@@ -3,6 +3,7 @@ import os
 import re
 import pysam
 from searcHPV.general import *
+import string
 
 ########################
 #get informative reads (SP + PE) from bam file
@@ -67,7 +68,9 @@ def extract_read_name(bam,out_dir,virRef,window):
             if '>' in each:
                 virus_chrm_list.append(each.split()[0].replace('>',''))
     for virus_chrm in virus_chrm_list:
-        fusionRes = f'{out_dir}/call_fusion/{virus_chrm}.all.filtered.clustered.result'
+        invalidCharacter = set(string.punctuation)
+        virus_chrm_file_name = virus_chrm.replace(invalidCharacter,"_")
+        fusionRes = f'{out_dir}/call_fusion/{virus_chrm_file_name}.all.filtered.clustered.result'
         check_file(fusionRes)
         with open(fusionRes) as candidate_in:
             candidate_in = candidate_in.read().rstrip()
